@@ -1,7 +1,7 @@
 #!/usr/bin/python
 
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ while 1:
     s = '/'+s[:-1][len(RM)+2:]
     if s: #UGH WHY WHY WHY!?!
         if s == '/usr/man/man1/solfege.1':
-            s = s + ".gz"
+            s = s + "*"
         sys.stdout.write(s)
         sys.stdout.write("\n")
 
