@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -298,7 +298,8 @@ class Gui(gtk.GtkVBox, cfg.ConfigUtils):
                     self.m_key_bindings[s]()
                     return 1
     def keymatch(self, event, cfname):
-        return (event.state, event.keyval) == utils.parse_key_string(self.get_string(cfname))
+        a, b = utils.parse_key_string(self.get_string(cfname))
+        return ((event.state & (GDK.CONTROL_MASK|GDK.SHIFT_MASK|GDK.MOD1_MASK)) == a) and (event.keyval == b)
     def setup_statisticsviewer(self, viewclass, heading):
         self.g_statview = viewclass(self.m_t.m_statistics, heading)
         self.g_statview.show()
