@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,6 @@
 from __future__ import nested_scopes
 
 import sys
-if '--inithack' in sys.argv:
-    import inithack
-    del sys.argv[sys.argv.index('--inithack')]
-
 import time, random
 from i18n import _
 import configureoutput
@@ -47,13 +43,13 @@ This is free software. It is covered by the GNU General Public License,
 and you are welcome to change it and/or distribute copies of it under
 certain conditions. Invoke as `solfege --warranty` for more information.
 
-Copyright (c) 2000-2001 by Tom Cato Amundsen <tca@gnu.org>
+Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen <tca@gnu.org>
             """ % configureoutput.VERSION_STRING
             sys.exit()
 
         if '-w' in argv or '--warranty' in argv:
             print """GNU Solfege %s
-Copyright (c) 2000-2001 by Tom Cato Amundsen <tca@gnu.org>
+Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen <tca@gnu.org>
 
     This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License version 2
@@ -83,8 +79,6 @@ sys.argv.append('--disable-sound')
 
 import locale
 import gtk
-if sys.platform == 'win32':
-    locale.setlocale(locale.LC_NUMERIC, "C")
 
 gtk.rc_parse("solfege.gtkrc")
 
@@ -130,6 +124,7 @@ import gnome, gnome.ui
 # FIXME
 from gnome.ui import *
 import GDK, os, const, string
+locale.setlocale(locale.LC_NUMERIC, "C")
 import app
 from htmlwidget import HtmlWidget
 import utils, history
@@ -227,7 +222,7 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
         if not self.g_about_window:
             self.g_about_window = gnome.ui.GnomeAbout(
                     'GNU Solfege', configureoutput.VERSION_STRING,
-                    'Copyright (C) 2000, 2001 Tom Cato Amundsen',
+                    'Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen',
                     ['Tom Cato Amundsen',
                      'Oliver Vollmer %s' % _("(toolbar icons)"),
                      'Giovanni Chierico %s' % _("(some lessonfiles)"),
