@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -243,3 +243,7 @@ class LessonStatistics(AbstractStatistics):
 class IntervallStatistics(Statistics):
     def key_to_pretty_name(self, key):
         return utils.int_to_intervallname(key, 1, 1)
+
+class HarmonicIntervallStatistics(Statistics):
+    def key_to_pretty_name(self, key):
+        return utils.int_to_intervallname(key, 1, 0)
